# coding: utf-8

"""
    Networks API

    Create, list, edit and delete public/private networks with the Network API. Use public networks to place multiple  servers on the same network or VLAN. Assign new servers with IP addresses from the same CIDR range. Use private  networks to avoid unnecessary egress data charges. Model your networks according to your business needs.<br> <br> <span class='pnap-api-knowledge-base-link'> Helpful knowledge base articles are available for  <a href='https://phoenixnap.com/kb/bmc-server-management-via-api#multi-private-backend-network-api' target='_blank'>multi-private backend networks</a> and <a href='https://phoenixnap.com/kb/bmc-server-management-via-api#ftoc-heading-15' target='_blank'>public networks</a>. </span><br> <br> <b>All URLs are relative to (https://api.phoenixnap.com/networks/v1/)</b> 

    The version of the OpenAPI document: 1.0
    Contact: support@phoenixnap.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Any, ClassVar, Dict, List, Optional
from pydantic import BaseModel, StrictInt, StrictStr
from pydantic import Field
from typing_extensions import Annotated
from pnap_network_api.models.network_membership import NetworkMembership
from pnap_network_api.models.public_network_ip_block import PublicNetworkIpBlock
try:
    from typing import Self
except ImportError:
    from typing_extensions import Self

class PublicNetwork(BaseModel):
    """
    Public Network details.
    """ # noqa: E501
    id: StrictStr = Field(description="The public network identifier.")
    vlan_id: StrictInt = Field(description="The VLAN of this public network.", alias="vlanId")
    memberships: List[NetworkMembership] = Field(description="A list of resources that are members of this public network.")
    name: Annotated[str, Field(min_length=1, strict=True, max_length=100)] = Field(description="The friendly name of this public network.")
    location: StrictStr = Field(description="The location of this public network. Supported values are `PHX`, `ASH`, `SGP`, `NLD`, `CHI`, `SEA` and `AUS`.")
    description: Optional[Annotated[str, Field(strict=True, max_length=250)]] = Field(default=None, description="The description of this public network.")
    status: StrictStr = Field(description="The status of the public network. Can have one of the following values: `BUSY`, `READY`, `DELETING` or `ERROR`.")
    created_on: datetime = Field(description="Date and time when this public network was created.", alias="createdOn")
    ip_blocks: List[PublicNetworkIpBlock] = Field(description="A list of IP Blocks that are associated with this public network.", alias="ipBlocks")
    __properties: ClassVar[List[str]] = ["id", "vlanId", "memberships", "name", "location", "description", "status", "createdOn", "ipBlocks"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of PublicNetwork from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        _dict = self.model_dump(
            by_alias=True,
            exclude={
            },
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in memberships (list)
        _items = []
        if self.memberships:
            for _item in self.memberships:
                if _item:
                    _items.append(_item.to_dict())
            _dict['memberships'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in ip_blocks (list)
        _items = []
        if self.ip_blocks:
            for _item in self.ip_blocks:
                if _item:
                    _items.append(_item.to_dict())
            _dict['ipBlocks'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Dict) -> Self:
        """Create an instance of PublicNetwork from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "vlanId": obj.get("vlanId"),
            "memberships": [NetworkMembership.from_dict(_item) for _item in obj.get("memberships")] if obj.get("memberships") is not None else None,
            "name": obj.get("name"),
            "location": obj.get("location"),
            "description": obj.get("description"),
            "status": obj.get("status"),
            "createdOn": obj.get("createdOn"),
            "ipBlocks": [PublicNetworkIpBlock.from_dict(_item) for _item in obj.get("ipBlocks")] if obj.get("ipBlocks") is not None else None
        })
        return _obj


